@@ -29,7 +29,7 @@ pub fn cmd<A: AsRef<str>, P: AsRef<Path>>(
 	let out = out.trim();
 	let out = String::from(out);
 	let res = child.wait()?.code().unwrap_or(0);
-	if print {
+	if print && !out.is_empty() {
 		println!("{}", out);
 	}
 	if throw && res != 0 {
@@ -45,25 +45,24 @@ pub fn has(path: &str) -> bool {
 	Path::new(path).exists()
 }
 
-pub fn isdir(path: &str) -> bool {
+pub fn is_dir(path: &str) -> bool {
 	Path::new(path).is_dir()
 }
 
+pub fn is_file(path: &str) -> bool {
+	Path::new(path).is_file()
+}
+
+pub fn cd(path: &str) -> Result<(), LizError> {
+	Ok(std::env::set_current_dir(path)?)
+}
+
 pub fn rn(origin: &str, destiny: &str) -> Result<(), LizError> {
 	Ok(fs::rename(origin, destiny)?)
 }
 
-pub fn cp_old(origin: &str, destiny: &str) -> Result<(), LizError> {
-	if has(destiny) {
-		let destiny_old = format!("{}_old", destiny);
-		rm(&destiny_old)?;
-		rn(destiny, &destiny_old)?;
-	}
-	cp(origin, destiny)
-}
-
 pub fn cp(origin: &str, destiny: &str) -> Result<(), LizError> {
-	if isdir(origin) {
+	if is_dir(origin) {
 		copy_directory(origin, destiny)?;
 	} else {
 		copy_file(origin, destiny)?;
@@ -71,6 +70,26 @@ pub fn cp(origin: &str, destiny: &str) -> Result<(), LizError> {
 	Ok(())
 }
 
+pub fn cp_tmp(origin: &str, destiny: &str) -> Result<(), LizError> {
+	if has(destiny) {
+		let mut temp_name: String = destiny
+			.chars()
+			.map(|x| match x {
+				'\\' => '_',
+				'/' => '_',
+				_ => x,
+			})
+			.collect();
+		let mut destiny_tmp = std::env::temp_dir().join(&temp_name);
+		while destiny_tmp.exists() {
+			temp_name.push_str("_");
+			destiny_tmp = std::env::temp_dir().join(&temp_name);
+		}
+		fs::rename(destiny, destiny_tmp)?;
+	}
+	cp(origin, destiny)
+}
+
 fn copy_directory(origin: impl AsRef<Path>, destiny: impl AsRef<Path>) -> Result<(), LizError> {
 	fs::create_dir_all(&destiny)?;
 	for entry in fs::read_dir(origin)? {
@@ -101,7 +120,7 @@ pub fn mv(origin: &str, destiny: &str) -> Result<(), LizError> {
 
 pub fn rm(path: &str) -> Result<(), LizError> {
 	Ok(if has(path) {
-		if isdir(path) {
+		if is_dir(path) {
 			fs::remove_dir_all(path)?
 		} else {
 			fs::remove_file(path)?
@@ -116,7 +135,7 @@ pub fn read(path: &str) -> Result<String, LizError> {
 	Ok(result)
 }
 
-pub fn mkdir(path: &str) -> Result<(), LizError> {
+pub fn mk_dir(path: &str) -> Result<(), LizError> {
 	fs::create_dir_all(path)?;
 	Ok(())
 }
